@@ -42,8 +42,8 @@ test_that("segregated scatterplot referenceLines", {
                            varAnnot             = z,
                            colorBy              = "Response",
                            graphType            = "Scatter2D",
-                           segregateVariablesBy = "Response",
-                           spiderBy             = "Subject",
+                           segregateVariablesBy = list(list("Response")),
+                           spiderBy             = list(list("Subject")),
                            title                = "Segregated Scatterplot - lines and labels",
                            xAxis                = list("Weeks"),
                            yAxis                = list("Change From Baseline %"),
@@ -142,7 +142,7 @@ test_that("segregated barplot and boxplot marker decorations", {
                            smpLabelRotate     = 90,
                            smpTitle           = "Species",
                            title              = "Segregated Barplot - marker decoration above each bar",
-                           segregateSamplesBy = list("Facet"),
+                           segregateSamplesBy = list(list("Facet")),
                            groupingFactors    = list("Species"),
                            layoutAdjust       = TRUE,
                            decorations        = list(marker = markers_list))
@@ -157,7 +157,7 @@ test_that("segregated barplot and boxplot marker decorations", {
                            smpLabelRotate     = 90,
                            smpTitle           = "Species",
                            title              = "Segregated Boxplot - marker decoration above each box",
-                           segregateSamplesBy = list("Facet"),
+                           segregateSamplesBy = list(list("Facet")),
                            groupingFactors    = list("Species"),
                            layoutAdjust       = TRUE,
                            decorations        = list(marker = markers_list))
@@ -210,7 +210,7 @@ test_that("double-segregated barplot and boxplot marker decorations", {
                            smpLabelRotate     = 90,
                            smpTitle           = "Species",
                            title              = "Double-segregated Barplot - marker decoration above each bar",
-                           segregateSamplesBy = list("Facet", "OtherFacet"),
+                           segregateSamplesBy = list(list("Facet"), list("OtherFacet")),
                            groupingFactors    = list("Species"),
                            layoutAdjust       = TRUE,
                            setMaxX            = 1.1 * max(data[var_names]),
@@ -226,7 +226,7 @@ test_that("double-segregated barplot and boxplot marker decorations", {
                            smpLabelRotate     = 90,
                            smpTitle           = "Species",
                            title              = "Double-segregated Boxplot - marker decoration above each box",
-                           segregateSamplesBy = list("Facet", "OtherFacet"),
+                           segregateSamplesBy = list(list("Facet"), list("OtherFacet")),
                            groupingFactors    = list("Species"),
                            layoutAdjust       = TRUE,
                            setMaxX            = 1.1 * max(data[var_names]),
@@ -252,7 +252,7 @@ test_that("segregated Boxplot decorations with different values", {
                            smpLabelRotate     = 90,
                            smpTitle           = "Species",
                            title              = "Segregated Boxplot - decorations with different values for each Species",
-                           segregateSamplesBy = list("Species"),
+                           segregateSamplesBy = list(list("Species")),
                            groupingFactors    = list("Species"),
                            layoutAdjust       = TRUE,
                            decorations        = list(line = list(list(align = "left", color = "rgb(255,0,0)", label = "Cutoff", value = 2, width = 2, scope = "setosa"),
@@ -280,7 +280,7 @@ test_that("segregated Boxplot decorations with same values", {
                            smpLabelRotate     = 90,
                            smpTitle           = "Species",
                            title              = "Segregated Boxplot - decoration should be on exactly the same height",
-                           segregateSamplesBy = list("Species"),
+                           segregateSamplesBy = list(list("Species")),
                            groupingFactors    = list("Species"),
                            layoutAdjust       = FALSE,
                            decorations        = list(line = list(list(align = "left", color = "rgb(255,0,0)", label = "Cutoff", value = 2, width = 2))))
@@ -309,7 +309,7 @@ test_that("segregated Boxplot decoration label position", {
                                graphOrientation   = "horizontal",
                                graphType          = "Boxplot",
                                groupingFactors    = list("dose"),
-                               segregateVariablesBy = list("Gene"),
+                               segregateVariablesBy = list(list("Gene")),
                                legendBox          = FALSE,
                                smpLabelRotate     = 90,
                                smpTitle           = "dose",
@@ -362,7 +362,7 @@ test_that("precalculated barplot - annotations", {
     # with smpAnnot data
     result <- canvasXpress(data                  = precalc.data2,
                            smpAnnot              = smp.data,
-                           segregateSamplesBy    = list("level"),
+                           segregateSamplesBy    = list(list("level")),
                            graphType             = "Bar",
                            graphOrientation      = "vertical",
                            smpLabelFontStyle     = "italic",
@@ -401,7 +401,7 @@ test_that("segregated and overlayed precalculated barplot - annotations", {
 
     result   <- canvasXpress(data                  = precalc.data,
                              smpAnnot              = smp.data,
-                             segregateSamplesBy    = list("level"),
+                             segregateSamplesBy    = list(list("level")),
                              smpOverlays           = list("Project"),
                              graphType             = "Bar",
                              graphOrientation      = "vertical",
